==> ejc-panhuo-api-3.0.0-20200819.010345-11-sources.jar: com/ejianc/business/panhuo/vo/OrderVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 订单实体
 * 
 * @author generator
 * 
 */
public class OrderVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long goodsId; // 资产主键
    private java.lang.String billCode; // 订单编号
    private java.lang.Long toolId; // 机具主键
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别末级
    private java.lang.String materialTypeName; // 物资类别末级名称
    private java.lang.String sourceId; // 物资来源ID
    private java.lang.Long systemId; // 所属系统ID
    private java.lang.String spec; // 规格型号
    private java.lang.String mainimgPath; // 资产主图URL
    private java.lang.Integer type; // 0-待确认，1-已完成，2-订单取消
    private java.lang.String unit; // 单位
    private java.math.BigDecimal orderprice; // 单价
    private java.math.BigDecimal ordernums; // 数量
    private java.math.BigDecimal ordermny; // 下单金额
    private java.math.BigDecimal price; // 成交单价
    private java.math.BigDecimal nums; // 成交数量
    private java.math.BigDecimal mny; // 成交金额
    private java.lang.String buyTime; // 购买时间
    private java.lang.String dealrTime; // 成交时间
    private java.lang.Long orderUserId; // 订购人
    private java.lang.String orderUserName; // 订购人名称
    private java.lang.Long confirmer; // 确认人
    private java.lang.String confirmName; // 确认人名称
    private java.lang.Long seller; // 发布人
    private java.lang.String sellerName; // 发布人名称
    private java.lang.String sellUserName; // 出售方联系人
    private java.lang.Long sellOrg; // 出售方组织主键
    private java.lang.String sellOrgName; // 出售方组织名称
    private java.lang.Long sellProject; // 出售方项目
    private java.lang.String sellProjectName; // 出售方项目名称
    private java.lang.Long sellAddressId; // 出售方地址主键
    private java.lang.String sellAddress; // 出售方详细地址
    private java.lang.String sellPhone; // 出售方联系电话
    private java.lang.String buyer; // 购买方联系人
    private java.lang.Long buyOrg; // 购买方组织主键
    private java.lang.String buyOrgName; // 购买方组织名称
    private java.lang.Long buyProject; // 购买方项目主键
    private java.lang.String buyProjectName; // 购买方项目名称
    private java.lang.Long buyAddressId; // 购买方地址主键
    private java.lang.String buyAddress; // 购买方详细地址
    private java.lang.String buyPhone; // 购买方电话
    private java.lang.String isPack; // 0-是  1-否
    private java.lang.String cancel; // 取消人
    private java.lang.String cancelTime; // 取消时间
    private java.lang.Integer cancelType; // 取消类型，0=买家，1=卖家，2-超时

    public String getSellUserName() {
        return sellUserName;
    }

    public void setSellUserName(String sellUserName) {
        this.sellUserName = sellUserName;
    }

    public Long getConfirmer() {
        return confirmer;
    }

    public void setConfirmer(Long confirmer) {
        this.confirmer = confirmer;
    }

    public String getConfirmName() {
        return confirmName;
    }

    public void setConfirmName(String confirmName) {
        this.confirmName = confirmName;
    }

    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }

    /**
     * 资产主键
     */
    public java.lang.Long getGoodsId() {
        return goodsId;
    }

    /**
     * 资产主键
     */
    public void setGoodsId(java.lang.Long goodsId) {
        this.goodsId = goodsId;
    }
    /**
     * 订单编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 订单编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 机具主键
     */
    public java.lang.Long getToolId() {
        return toolId;
    }

    /**
     * 机具主键
     */
    public void setToolId(java.lang.Long toolId) {
        this.toolId = toolId;
    }
    /**
     * 物资主键
     */
    @ReferSerialTransfer(referCode="Material001")
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    @ReferDeserialTransfer
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别末级
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别末级
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别末级名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别末级名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 物资来源ID
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 所属系统ID
     */
    public java.lang.Long getSystemId() {
        return systemId;
    }

    /**
     * 所属系统ID
     */
    public void setSystemId(java.lang.Long systemId) {
        this.systemId = systemId;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 资产主图URL
     */
    public java.lang.String getMainimgPath() {
        return mainimgPath;
    }

    /**
     * 资产主图URL
     */
    public void setMainimgPath(java.lang.String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    /**
     * 0-待确认，1-已完成，2-订单取消
     */
    public java.lang.Integer getType() {
        return type;
    }

    /**
     * 0-待确认，1-已完成，2-订单取消
     */
    public void setType(java.lang.Integer type) {
        this.type = type;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 单价
     */
    public java.math.BigDecimal getOrderprice() {
        return orderprice;
    }

    /**
     * 单价
     */
    public void setOrderprice(java.math.BigDecimal orderprice) {
        this.orderprice = orderprice;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getOrdernums() {
        return ordernums;
    }

    /**
     * 数量
     */
    public void setOrdernums(java.math.BigDecimal ordernums) {
        this.ordernums = ordernums;
    }
    /**
     * 下单金额
     */
    public java.math.BigDecimal getOrdermny() {
        return ordermny;
    }

    /**
     * 下单金额
     */
    public void setOrdermny(java.math.BigDecimal ordermny) {
        this.ordermny = ordermny;
    }
    /**
     * 成交单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 成交单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 成交数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 成交数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 成交金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 成交金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 购买时间
     */
    public java.lang.String getBuyTime() {
        return buyTime;
    }

    /**
     * 购买时间
     */
    public void setBuyTime(java.lang.String buyTime) {
        this.buyTime = buyTime;
    }
    /**
     * 成交时间
     */
    public java.lang.String getDealrTime() {
        return dealrTime;
    }

    /**
     * 成交时间
     */
    public void setDealrTime(java.lang.String dealrTime) {
        this.dealrTime = dealrTime;
    }
    /**
     * 订购人
     */
    public java.lang.Long getOrderUserId() {
        return orderUserId;
    }

    /**
     * 订购人
     */
    public void setOrderUserId(java.lang.Long orderUserId) {
        this.orderUserId = orderUserId;
    }
    /**
     * 订购人名称
     */
    public java.lang.String getOrderUserName() {
        return orderUserName;
    }

    /**
     * 订购人名称
     */
    public void setOrderUserName(java.lang.String orderUserName) {
        this.orderUserName = orderUserName;
    }
    /**
     * 出售方联系人
     */
    public java.lang.Long getSeller() {
        return seller;
    }

    /**
     * 出售方联系人
     */
    public void setSeller(java.lang.Long seller) {
        this.seller = seller;
    }
    /**
     * 出售方组织主键
     */
    public java.lang.Long getSellOrg() {
        return sellOrg;
    }

    /**
     * 出售方组织主键
     */
    public void setSellOrg(java.lang.Long sellOrg) {
        this.sellOrg = sellOrg;
    }
    /**
     * 出售方组织名称
     */
    public java.lang.String getSellOrgName() {
        return sellOrgName;
    }

    /**
     * 出售方组织名称
     */
    public void setSellOrgName(java.lang.String sellOrgName) {
        this.sellOrgName = sellOrgName;
    }
    /**
     * 出售方项目
     */
    public java.lang.Long getSellProject() {
        return sellProject;
    }

    /**
     * 出售方项目
     */
    public void setSellProject(java.lang.Long sellProject) {
        this.sellProject = sellProject;
    }
    /**
     * 出售方项目名称
     */
    public java.lang.String getSellProjectName() {
        return sellProjectName;
    }

    /**
     * 出售方项目名称
     */
    public void setSellProjectName(java.lang.String sellProjectName) {
        this.sellProjectName = sellProjectName;
    }
    /**
     * 出售方地址主键
     */
    @ReferSerialTransfer(referCode="panhuo-addressRef")
    public java.lang.Long getSellAddressId() {
        return sellAddressId;
    }

    /**
     * 出售方地址主键
     */
    @ReferDeserialTransfer
    public void setSellAddressId(java.lang.Long sellAddressId) {
        this.sellAddressId = sellAddressId;
    }
    /**
     * 出售方详细地址
     */
    public java.lang.String getSellAddress() {
        return sellAddress;
    }

    /**
     * 出售方详细地址
     */
    public void setSellAddress(java.lang.String sellAddress) {
        this.sellAddress = sellAddress;
    }
    /**
     * 出售方联系电话
     */
    public java.lang.String getSellPhone() {
        return sellPhone;
    }

    /**
     * 出售方联系电话
     */
    public void setSellPhone(java.lang.String sellPhone) {
        this.sellPhone = sellPhone;
    }
    /**
     * 购买方联系人
     */
    public java.lang.String getBuyer() {
        return buyer;
    }

    /**
     * 购买方联系人
     */
    public void setBuyer(java.lang.String buyer) {
        this.buyer = buyer;
    }
    /**
     * 购买方组织主键
     */
    public java.lang.Long getBuyOrg() {
        return buyOrg;
    }

    /**
     * 购买方组织主键
     */
    public void setBuyOrg(java.lang.Long buyOrg) {
        this.buyOrg = buyOrg;
    }
    /**
     * 购买方组织名称
     */
    public java.lang.String getBuyOrgName() {
        return buyOrgName;
    }

    /**
     * 购买方组织名称
     */
    public void setBuyOrgName(java.lang.String buyOrgName) {
        this.buyOrgName = buyOrgName;
    }
    /**
     * 购买方项目主键
     */
    public java.lang.Long getBuyProject() {
        return buyProject;
    }

    /**
     * 购买方项目主键
     */
    public void setBuyProject(java.lang.Long buyProject) {
        this.buyProject = buyProject;
    }
    /**
     * 购买方项目名称
     */
    public java.lang.String getBuyProjectName() {
        return buyProjectName;
    }

    /**
     * 购买方项目名称
     */
    public void setBuyProjectName(java.lang.String buyProjectName) {
        this.buyProjectName = buyProjectName;
    }
    /**
     * 购买方地址主键
     */
    @ReferSerialTransfer(referCode="panhuo-addressRef")
    public java.lang.Long getBuyAddressId() {
        return buyAddressId;
    }

    /**
     * 购买方地址主键
     */
    @ReferDeserialTransfer
    public void setBuyAddressId(java.lang.Long buyAddressId) {
        this.buyAddressId = buyAddressId;
    }
    /**
     * 购买方详细地址
     */
    public java.lang.String getBuyAddress() {
        return buyAddress;
    }

    /**
     * 购买方详细地址
     */
    public void setBuyAddress(java.lang.String buyAddress) {
        this.buyAddress = buyAddress;
    }
    /**
     * 购买方电话
     */
    public java.lang.String getBuyPhone() {
        return buyPhone;
    }

    /**
     * 购买方电话
     */
    public void setBuyPhone(java.lang.String buyPhone) {
        this.buyPhone = buyPhone;
    }

    public String getIsPack() {
        return isPack;
    }

    public void setIsPack(String isPack) {
        this.isPack = isPack;
    }

    /**
     * 取消人
     */
    public java.lang.String getCancel() {
        return cancel;
    }

    /**
     * 取消人
     */
    public void setCancel(java.lang.String cancel) {
        this.cancel = cancel;
    }
    /**
     * 取消时间
     */
    public java.lang.String getCancelTime() {
        return cancelTime;
    }

    /**
     * 取消时间
     */
    public void setCancelTime(java.lang.String cancelTime) {
        this.cancelTime = cancelTime;
    }
    /**
     * 取消类型，0=买家，1=卖家，2-超时
     */
    public java.lang.Integer getCancelType() {
        return cancelType;
    }

    /**
     * 取消类型，0=买家，1=卖家，2-超时
     */
    public void setCancelType(java.lang.Integer cancelType) {
        this.cancelType = cancelType;
    }
    
}

==> ejc-panhuo-api-3.0.0-20200820.094148-23-sources.jar: com/ejianc/business/panhuo/vo/OrderVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 订单实体
 * 
 * @author generator
 * 
 */
public class OrderVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long goodsId; // 资产主键
    private java.lang.String billCode; // 订单编号
    private java.lang.Long toolId; // 机具主键
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别末级
    private java.lang.String materialTypeName; // 物资类别末级名称
    private java.lang.String sourceId; // 物资来源ID
    private java.lang.Long systemId; // 所属系统ID
    private java.lang.String spec; // 规格型号
    private java.lang.String mainimgPath; // 资产主图URL
    private java.lang.Integer type; // 0-待确认，1-已完成，2-订单取消
    private java.lang.String unit; // 单位
    private java.math.BigDecimal orderprice; // 单价
    private java.math.BigDecimal ordernums; // 数量
    private java.math.BigDecimal ordermny; // 下单金额
    private java.math.BigDecimal price; // 成交单价
    private java.math.BigDecimal nums; // 成交数量
    private java.math.BigDecimal mny; // 成交金额
    @JsonFormat(
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date buyTime; // 购买时间
    @JsonFormat(
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date dealrTime; // 成交时间
    private java.lang.Long orderUserId; // 订购人
    private java.lang.String orderUserName; // 订购人名称
    private java.lang.Long confirmer; // 确认人
    private java.lang.String confirmName; // 确认人名称
    private java.lang.Long seller; // 发布人
    private java.lang.String sellerName; // 发布人名称
    private java.lang.String sellUserName; // 出售方联系人
    private java.lang.Long sellOrg; // 出售方组织主键
    private java.lang.String sellOrgName; // 出售方组织名称
    private java.lang.Long sellProject; // 出售方项目
    private java.lang.String sellProjectName; // 出售方项目名称
    private java.lang.Long sellAddressId; // 出售方地址主键
    private java.lang.String sellAddress; // 出售方详细地址
    private java.lang.String sellPhone; // 出售方联系电话
    private java.lang.String buyer; // 购买方联系人
    private java.lang.Long buyOrg; // 购买方组织主键
    private java.lang.String buyOrgName; // 购买方组织名称
    private java.lang.Long buyProject; // 购买方项目主键
    private java.lang.String buyProjectName; // 购买方项目名称
    private java.lang.Long buyAddressId; // 购买方地址主键
    private java.lang.String buyAddress; // 购买方详细地址
    private java.lang.String buyPhone; // 购买方电话
    private java.lang.String isPack; // 0-是  1-否
    private java.lang.String cancel; // 取消人
    @JsonFormat(
            pattern = "yyyy-MM-dd HH:mm:ss",
            timezone = "GMT+8"
    )
    private Date cancelTime; // 取消时间
    private java.lang.Integer cancelType; // 取消类型，0=买家，1=卖家，2-超时

    public String getSellUserName() {
        return sellUserName;
    }

    public void setSellUserName(String sellUserName) {
        this.sellUserName = sellUserName;
    }

    public Long getConfirmer() {
        return confirmer;
    }

    public void setConfirmer(Long confirmer) {
        this.confirmer = confirmer;
    }

    public String getConfirmName() {
        return confirmName;
    }

    public void setConfirmName(String confirmName) {
        this.confirmName = confirmName;
    }

    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }

    /**
     * 资产主键
     */
    public java.lang.Long getGoodsId() {
        return goodsId;
    }

    /**
     * 资产主键
     */
    public void setGoodsId(java.lang.Long goodsId) {
        this.goodsId = goodsId;
    }
    /**
     * 订单编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 订单编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 机具主键
     */
    public java.lang.Long getToolId() {
        return toolId;
    }

    /**
     * 机具主键
     */
    public void setToolId(java.lang.Long toolId) {
        this.toolId = toolId;
    }
    /**
     * 物资主键
     */
    @ReferSerialTransfer(referCode="Material001")
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    @ReferDeserialTransfer
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别末级
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别末级
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别末级名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别末级名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资来源ID
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 物资来源ID
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 所属系统ID
     */
    public java.lang.Long getSystemId() {
        return systemId;
    }

    /**
     * 所属系统ID
     */
    public void setSystemId(java.lang.Long systemId) {
        this.systemId = systemId;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 资产主图URL
     */
    public java.lang.String getMainimgPath() {
        return mainimgPath;
    }

    /**
     * 资产主图URL
     */
    public void setMainimgPath(java.lang.String mainimgPath) {
        this.mainimgPath = mainimgPath;
    }
    /**
     * 0-待确认，1-已完成，2-订单取消
     */
    public java.lang.Integer getType() {
        return type;
    }

    /**
     * 0-待确认，1-已完成，2-订单取消
     */
    public void setType(java.lang.Integer type) {
        this.type = type;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 单价
     */
    public java.math.BigDecimal getOrderprice() {
        return orderprice;
    }

    /**
     * 单价
     */
    public void setOrderprice(java.math.BigDecimal orderprice) {
        this.orderprice = orderprice;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getOrdernums() {
        return ordernums;
    }

    /**
     * 数量
     */
    public void setOrdernums(java.math.BigDecimal ordernums) {
        this.ordernums = ordernums;
    }
    /**
     * 下单金额
     */
    public java.math.BigDecimal getOrdermny() {
        return ordermny;
    }

    /**
     * 下单金额
     */
    public void setOrdermny(java.math.BigDecimal ordermny) {
        this.ordermny = ordermny;
    }
    /**
     * 成交单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 成交单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 成交数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 成交数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 成交金额
     */
    public java.math.BigDecimal getMny() {
        return mny;
    }

    /**
     * 成交金额
     */
    public void setMny(java.math.BigDecimal mny) {
        this.mny = mny;
    }

    public Date getBuyTime() {
        return buyTime;
    }

    public void setBuyTime(Date buyTime) {
        this.buyTime = buyTime;
    }

    public Date getDealrTime() {
        return dealrTime;
    }

    public void setDealrTime(Date dealrTime) {
        this.dealrTime = dealrTime;
    }

    public void setCancelTime(Date cancelTime) {
        this.cancelTime = cancelTime;
    }

    /**
     * 订购人
     */
    public java.lang.Long getOrderUserId() {
        return orderUserId;
    }

    /**
     * 订购人
     */
    public void setOrderUserId(java.lang.Long orderUserId) {
        this.orderUserId = orderUserId;
    }
    /**
     * 订购人名称
     */
    public java.lang.String getOrderUserName() {
        return orderUserName;
    }

    /**
     * 订购人名称
     */
    public void setOrderUserName(java.lang.String orderUserName) {
        this.orderUserName = orderUserName;
    }
    /**
     * 出售方联系人
     */
    public java.lang.Long getSeller() {
        return seller;
    }

    /**
     * 出售方联系人
     */
    public void setSeller(java.lang.Long seller) {
        this.seller = seller;
    }
    /**
     * 出售方组织主键
     */
    public java.lang.Long getSellOrg() {
        return sellOrg;
    }

    /**
     * 出售方组织主键
     */
    public void setSellOrg(java.lang.Long sellOrg) {
        this.sellOrg = sellOrg;
    }
    /**
     * 出售方组织名称
     */
    public java.lang.String getSellOrgName() {
        return sellOrgName;
    }

    /**
     * 出售方组织名称
     */
    public void setSellOrgName(java.lang.String sellOrgName) {
        this.sellOrgName = sellOrgName;
    }
    /**
     * 出售方项目
     */
    public java.lang.Long getSellProject() {
        return sellProject;
    }

    /**
     * 出售方项目
     */
    public void setSellProject(java.lang.Long sellProject) {
        this.sellProject = sellProject;
    }
    /**
     * 出售方项目名称
     */
    public java.lang.String getSellProjectName() {
        return sellProjectName;
    }

    /**
     * 出售方项目名称
     */
    public void setSellProjectName(java.lang.String sellProjectName) {
        this.sellProjectName = sellProjectName;
    }
    /**
     * 出售方地址主键
     */
    @ReferSerialTransfer(referCode="panhuo-addressRef")
    public java.lang.Long getSellAddressId() {
        return sellAddressId;
    }

    /**
     * 出售方地址主键
     */
    @ReferDeserialTransfer
    public void setSellAddressId(java.lang.Long sellAddressId) {
        this.sellAddressId = sellAddressId;
    }
    /**
     * 出售方详细地址
     */
    public java.lang.String getSellAddress() {
        return sellAddress;
    }

    /**
     * 出售方详细地址
     */
    public void setSellAddress(java.lang.String sellAddress) {
        this.sellAddress = sellAddress;
    }
    /**
     * 出售方联系电话
     */
    public java.lang.String getSellPhone() {
        return sellPhone;
    }

    /**
     * 出售方联系电话
     */
    public void setSellPhone(java.lang.String sellPhone) {
        this.sellPhone = sellPhone;
    }
    /**
     * 购买方联系人
     */
    public java.lang.String getBuyer() {
        return buyer;
    }

    /**
     * 购买方联系人
     */
    public void setBuyer(java.lang.String buyer) {
        this.buyer = buyer;
    }
    /**
     * 购买方组织主键
     */
    public java.lang.Long getBuyOrg() {
        return buyOrg;
    }

    /**
     * 购买方组织主键
     */
    public void setBuyOrg(java.lang.Long buyOrg) {
        this.buyOrg = buyOrg;
    }
    /**
     * 购买方组织名称
     */
    public java.lang.String getBuyOrgName() {
        return buyOrgName;
    }

    /**
     * 购买方组织名称
     */
    public void setBuyOrgName(java.lang.String buyOrgName) {
        this.buyOrgName = buyOrgName;
    }
    /**
     * 购买方项目主键
     */
    public java.lang.Long getBuyProject() {
        return buyProject;
    }

    /**
     * 购买方项目主键
     */
    public void setBuyProject(java.lang.Long buyProject) {
        this.buyProject = buyProject;
    }
    /**
     * 购买方项目名称
     */
    public java.lang.String getBuyProjectName() {
        return buyProjectName;
    }

    /**
     * 购买方项目名称
     */
    public void setBuyProjectName(java.lang.String buyProjectName) {
        this.buyProjectName = buyProjectName;
    }
    /**
     * 购买方地址主键
     */
    @ReferSerialTransfer(referCode="panhuo-addressRef")
    public java.lang.Long getBuyAddressId() {
        return buyAddressId;
    }

    /**
     * 购买方地址主键
     */
    @ReferDeserialTransfer
    public void setBuyAddressId(java.lang.Long buyAddressId) {
        this.buyAddressId = buyAddressId;
    }
    /**
     * 购买方详细地址
     */
    public java.lang.String getBuyAddress() {
        return buyAddress;
    }

    /**
     * 购买方详细地址
     */
    public void setBuyAddress(java.lang.String buyAddress) {
        this.buyAddress = buyAddress;
    }
    /**
     * 购买方电话
     */
    public java.lang.String getBuyPhone() {
        return buyPhone;
    }

    /**
     * 购买方电话
     */
    public void setBuyPhone(java.lang.String buyPhone) {
        this.buyPhone = buyPhone;
    }

    public String getIsPack() {
        return isPack;
    }

    public void setIsPack(String isPack) {
        this.isPack = isPack;
    }

    /**
     * 取消人
     */
    public java.lang.String getCancel() {
        return cancel;
    }

    /**
     * 取消人
     */
    public void setCancel(java.lang.String cancel) {
        this.cancel = cancel;
    }
    /**
     * 取消类型，0=买家，1=卖家，2-超时
     */
    public java.lang.Integer getCancelType() {
        return cancelType;
    }

    /**
     * 取消类型，0=买家，1=卖家，2-超时
     */
    public void setCancelType(java.lang.Integer cancelType) {
        this.cancelType = cancelType;
    }
    
}
